# OmeMetadatSource


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ome_metadata_url** | **str** |  | 

## Example

```python
from bia_integrator_api.models.ome_metadat_source import OmeMetadatSource

# TODO update the JSON string below
json = "{}"
# create an instance of OmeMetadatSource from a JSON string
ome_metadat_source_instance = OmeMetadatSource.from_json(json)
# print the JSON string representation of the object
print OmeMetadatSource.to_json()

# convert the object into a dict
ome_metadat_source_dict = ome_metadat_source_instance.to_dict()
# create an instance of OmeMetadatSource from a dict
ome_metadat_source_form_dict = ome_metadat_source.from_dict(ome_metadat_source_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


